Setup - Alpha Documentation

Skip to content

# Alpha system

## OS configuration

Important

make sure that Git is well configured.

### Python

- Python 3.10.4 is required. Anaconda or Miniconda could be used.

There is no constraint but the usual structure is to have:

- a user per configuration (mes, mesacc, mesint and mesdev for exemple)
- three location per user:
  - /home/USER/APP_NAME for sources
  - /home/USER/configs for configurations
  - /application/USER/APP_NAME for tmp files and logs

Note

This is configured within the conf.json file and could be modified

## Setup

If you just want to use the system go for the classic way and if you want to modify it use the sources integration.

### Classic

The default installation procedure is:

    pip install alphaz

It will install all the dependencies automatically.

### Using sources

If you want to edit the sources you could use this procedure to clone the sources and configure it as a sub module

1. Clone alphaz from the repository https://github.com/ZAurele/alphaz.git

       cd <your_project_repository>
       git clone https://github.com/ZAurele/alphaz.git

2. Launch the setup, it will install all the dependencies and other magical actions.

       python setup.py

3. Define it as a submodule in your project

## Dependencies

Main dependencies are automatically installed, however if you need specific ones, you will have to install them manually

### Oracle

Oracle client

## Configuration

### Angular

    {
      "compilerOptions": {
        "baseUrl": "./src",
        "paths": {
          "@services/*": ["app/services/*", "src/app/services/*"],
          "@views/*": ["app/views/*", "src/app/views/*"],
          "@models/*": ["app/models/*", "src/app/models/*"],
          "@components/*": ["app/components/*", "src/app/components/*"],
          "@alphaa/*": ["alphaa/*", "src/alphaa/*"],
          "@layout/*": ["app/layout/*", "src/app/layout/*"],
          "@envs/*": ["environments/*", "src/environments/*"],
          "@constants/*": ["app/constants/*", "src/app/constants/*"]
        }
      }
    }